@@ -16,8 +16,7 @@
     # si il est non nul, doit tre de dimensions (nombre de niveaux de x[,1] , 2) et
     # contenir les coordonnes dans l'ordre de unique(x[,1])
     x.area <- x
-    if(dev.cur() == 1) plot.new()
-    opar <- par(mar = par("mar")) #, new = par("new")
+    opar <- par(mar = par("mar"), new = par("new"))
     on.exit(par(opar))
     par(mar = c(0.1, 0.1, 0.1, 0.1))
     if (!is.factor(x.area[, 1])) 
@@ -164,8 +163,6 @@
     class(res) <- "polylist"
     attr(res, "region.id") <- label.poly
     attr(res, "region.rect") <- r0
-    # message de Stphane Dray du 06/02/2004
-    attr(res,"maplim") <- list(x=range(x1),y=range(x2))
     return(res)
 } 
 
