@@ -116,7 +116,7 @@
 }
 
 ############ scatterutil.chull #################
-"scatterutil.chull" <- function (x, y, fac, optchull = c(0.25, 0.5, 0.75, 1), col=rep(1,length(levels(fac)))) {
+"scatterutil.chull" <- function (x, y, fac, optchull = c(0.25, 0.5, 0.75, 1)) {
     if (!is.factor(fac)) 
         return(invisible())
     if (length(x) != length(fac)) 
@@ -141,21 +141,21 @@
             if ((taux <= cref) & (cref == 1)) {
                 cref <- 0.75
                 if (any(optchull == 1)) 
-                  polygon(x2, y2, lty = 1, border=col[i])
+                  polygon(x2, y2, lty = 1)
             }
             if ((taux <= cref) & (cref == 0.75)) {
                 if (any(optchull == 0.75)) 
-                  polygon(x2, y2, lty = 5, border=col[i])
+                  polygon(x2, y2, lty = 5)
                 cref <- 0.5
             }
             if ((taux <= cref) & (cref == 0.5)) {
                 if (any(optchull == 0.5)) 
-                  polygon(x2, y2, lty = 3, border=col[i])
+                  polygon(x2, y2, lty = 3)
                 cref <- 0.25
             }
             if ((taux <= cref) & (cref == 0.25)) {
                 if (any(optchull == 0.25)) 
-                  polygon(x2, y2, lty = 2, border=col[i])
+                  polygon(x2, y2, lty = 2)
                 cref <- 0
             }
             x1 <- x1[-num]
@@ -166,7 +166,7 @@
 }
 
 ############ scatterutil.eigen #################
-"scatterutil.eigen" <- function (w, xmax = length(w), ymin=0, ymax = max(w), wsel = 1, sub = "Eigenvalues",
+"scatterutil.eigen" <- function (w, xmax = length(w), ymax = max(w), wsel = 1, sub = "Eigen values",
     csub = 2, possub = "topright") 
 {
     opar <- par(mar = par("mar"))
@@ -176,20 +176,20 @@
         w <- c(w, rep(0, xmax - length(w)))
     col.w <- rep(grey(0.8), length(w))
     col.w[wsel] <- grey(0)
-    barplot(w, col = col.w, ylim = c(ymin, ymax))
+    barplot(w, col = col.w, ylim = c(0, ymax))
     scatterutil.sub(cha = sub, csub = csub, possub = possub)
 }
 
 ############ scatterutil.ellipse #################
-"scatterutil.ellipse" <- function (x, y, z, cellipse, axesell, coul = rep(1,length(x))) 
-{
-    if (any(is.na(z))) 
-        return(invisible())
-    if (sum(z * z) == 0) 
-        return(invisible())
+"scatterutil.ellipse" <- function (x, y, z, cellipse, axesell) {
+   
+    # modif du vendredi, mars 28, 2003 at 08:01 ajout des tests 
+    if (any(is.na(z)))  return (invisible())
+    if (sum(z*z)==0) return (invisible())
+    
     util.ellipse <- function(mx, my, vx, cxy, vy, coeff) {
         lig <- 100
-        epsi <- 1e-10
+        epsi <- 1e-05
         x <- 0
         y <- 0
         if (vx < 0) 
@@ -257,17 +257,16 @@
     ell <- util.ellipse(m1, m2, v1, cxy, v2, cellipse)
     if (is.null(ell)) 
         return(invisible())
-    polygon(ell$x, ell$y, border=coul)
+    polygon(ell$x, ell$y)
     if (axesell) 
         segments(ell$seg1[1], ell$seg1[2], ell$seg1[3], ell$seg1[4], 
-            lty = 2, col=coul)
+            lty = 2)
     if (axesell) 
         segments(ell$seg2[1], ell$seg2[2], ell$seg2[3], ell$seg2[4], 
-            lty = 2, col=coul)
+            lty = 2)
 }
-
 ############ scatterutil.eti.circ #################
-"scatterutil.eti.circ" <- function (x, y, label, clabel, origin=c(0,0), boxes=TRUE) {
+"scatterutil.eti.circ" <- function (x, y, label, clabel, origin=c(0,0)) {
     if (is.null(label)) 
         return(invisible())
     # message de JT warning pour R 1.7 modif samedi, mars 29, 2003 at 14:31
@@ -283,36 +282,32 @@
         cha <- as.character(label[i])
         cha <- paste(" ", cha, " ", sep = "")
         cex0 <- par("cex") * clabel
-        
-        if (boxes) {
-            xh <- strwidth(cha, cex = cex0)
-            yh <- strheight(cha, cex = cex0) * 5/6
-            if ((xref[i] > yref[i]) & (xref[i] > -yref[i])) {
-                x1 <- x[i] + xh/2
-                y1 <- y[i]
-            }
-            else if ((xref[i] > yref[i]) & (xref[i] <= (-yref[i]))) {
-                x1 <- x[i]
-                y1 <- y[i] - yh
-            }
-            else if ((xref[i] <= yref[i]) & (xref[i] <= (-yref[i]))) {
-                x1 <- x[i] - xh/2
-                y1 <- y[i]
-            }
-            else if ((xref[i] <= yref[i]) & (xref[i] > (-yref[i]))) {
-                x1 <- x[i]
-                y1 <- y[i] + yh
-            }
-            rect(x1 - xh/2, y1 - yh, x1 + xh/2, y1 + yh, col = "white", 
-                border = 1)
+        xh <- strwidth(cha, cex = cex0)
+        yh <- strheight(cha, cex = cex0) * 5/6
+        if ((xref[i] > yref[i]) & (xref[i] > -yref[i])) {
+            x1 <- x[i] + xh/2
+            y1 <- y[i]
         }
+        else if ((xref[i] > yref[i]) & (xref[i] <= (-yref[i]))) {
+            x1 <- x[i]
+            y1 <- y[i] - yh
+        }
+        else if ((xref[i] <= yref[i]) & (xref[i] <= (-yref[i]))) {
+            x1 <- x[i] - xh/2
+            y1 <- y[i]
+        }
+        else if ((xref[i] <= yref[i]) & (xref[i] > (-yref[i]))) {
+            x1 <- x[i]
+            y1 <- y[i] + yh
+        }
+        rect(x1 - xh/2, y1 - yh, x1 + xh/2, y1 + yh, col = "white", 
+            border = 1)
         text(x1, y1, cha, cex = cex0)
     }
 }
 
 ############ scatterutil.eti #################
-"scatterutil.eti" <- function (x, y, label, clabel, boxes=TRUE, coul = rep(1,length(x))) 
-{
+"scatterutil.eti" <- function (x, y, label, clabel) {
     if (length(label) == 0) 
         return(invisible())
     if (is.null(label)) 
@@ -323,18 +318,16 @@
         cha <- as.character(label[i])
         cha <- paste(" ", cha, " ", sep = "")
         cex0 <- par("cex") * clabel
+        xh <- strwidth(cha, cex = cex0)
+        yh <- strheight(cha, cex = cex0) * 5/3
         x1 <- x[i]
         y1 <- y[i]
-        if (boxes) {
-        	xh <- strwidth(cha, cex = cex0)
-        	yh <- strheight(cha, cex = cex0) * 5/3
-            rect(x1 - xh/2, y1 - yh/2, x1 + xh/2, y1 + yh/2, col= "white", border = coul[i])
-        }
-        text(x1, y1, cha, cex = cex0, col=coul[i])
+        rect(x1 - xh/2, y1 - yh/2, x1 + xh/2, y1 + yh/2, col = "white", 
+            border = 1)
+        text(x1, y1, cha, cex = cex0)
     }
 }
 
-
 ############ scatterutil.grid #################
 "scatterutil.grid" <- function (cgrid) {
     col <- "lightgray"
@@ -478,19 +471,17 @@
     return(xynew)
 }
 ############ scatterutil.star #################
-"scatterutil.star" <- function (x, y, z, cstar, coul = rep(1,length(x))) 
-{
+"scatterutil.star" <- function (x, y, z, cstar) {
     z <- z/sum(z)
     x1 <- sum(x * z)
     y1 <- sum(y * z)
     for (i in which(z > 0)) {
         hx <- cstar * (x[i] - x1)
         hy <- cstar * (y[i] - y1)
-        segments(x1, y1, x1 + hx, y1 + hy, col=coul)
+        segments(x1, y1, x1 + hx, y1 + hy)
     }
 }
 
-
 ############ scatterutil.sub #################
 "scatterutil.sub" <- function (cha, csub, possub = "bottomleft") {
     cha <- as.character(cha)
